@@ -42,7 +42,7 @@ class oblique_np(basic_manifold_np):
 
 
     def JC(self, X, Lambda):
-        return X * Lambda
+        return 2 * X * Lambda
 
     
     def C(self, X):
