@@ -2,6 +2,7 @@ import torch
 from collections import OrderedDict
 
 from .basic_manifold_torch import basic_manifold_torch
+from torch.nn.parameter import Parameter
 
 
 class stiefel_torch(basic_manifold_torch):
@@ -19,7 +20,7 @@ class stiefel_torch(basic_manifold_torch):
 
         super().__init__('Stiefel',var_shape, (*self.dim, self._p,self._p),   device= self.device ,dtype= self.dtype)
         # self._parameters = OrderedDict()
-        self._parameters['Ip'] = torch.diag_embed(torch.ones((*self.dim, self._p), device=self.device, dtype=self.dtype))
+        self._parameters['Ip'] = Parameter(torch.diag_embed(torch.ones((*self.dim, self._p), device=self.device, dtype=self.dtype)), False)
         self.Ip = self._parameters['Ip']
 
 
